@@ -21,7 +21,8 @@
 // TauSpinner headers
 #include "TauSpinner/SimpleParticle.h"
 #include "TauSpinner/tau_reweight_lib.h"
-#include "TauSpinner/read_particles_from_TAUOLA.h"
+
+#include "read_particles_from_TAUOLA.h"
 
 // ROOT headers
 #include "TCanvas.h"
