@@ -1,7 +1,7 @@
 /** 
 
  @mainpage C++ Interface to Tauola 
- @brief Description of Tauola Interface in C++
+ @brief Description of Tauola Interface in C++.  WARNING for Doxygen sub-pages: Namespaces, Data Structures, Files, Directorises. All describe the development  version. For the release of particular choice, its doxygen documentation is included in the corresponding distribution tar-ball. 
 
  @authors Nadia Davidson, Gizo Nanava, Tomasz Przedzinski, Elzbieta Richter-Was, Zbigniew Was
 
@@ -9,29 +9,29 @@
 
  @section download1 New release
 
- The source code and documentation for release 1.1.5
- - <a href="resources/TAUOLA.1.1.5/Tauola_interface_design.1.1.5.pdf">Tauola_interface_design.1.1.5.pdf</a> full software documentation includes updates with respect to
+ The source code and documentation for Tauola release 1.1.10 (and of TauSpinner release 2.1.3) 
+ - <a href="resources/TAUOLA.1.1.10/Tauola_interface_design.1.1.10.pdf">Tauola_interface_design.1.1.9.pdf</a> full software documentation includes updates with respect to
 the preprint version.
- - <a href="resources/TAUOLA.1.1.5/TAUOLA.1.1.5-LHC.tar.gz">TAUOLA source code for the LHC</a>
-(or <a href="resources/TAUOLA.1.1.5/TAUOLA.1.1.5.tar.gz">TAUOLA source code with full TAUOLA FORTRAN</a>
+ - <a href="resources/TAUOLA.1.1.10/TAUOLA.1.1.10-LHC.tar.gz">TAUOLA source code for the LHC</a>
+(or <a href="resources/TAUOLA.1.1.10/TAUOLA.1.1.10.tar.gz">TAUOLA source code with full TAUOLA FORTRAN</a>
  enabling changes of code/models for tau decay hadronic currents)
-tarball and its <a href="resources/TAUOLA.1.1.5/svn_info_tauola.1.1.5.txt">revision info</a> SVN tag, tarball
-creation date/time, etc. For updates with respect to release 1.0 see <a href="resources/TAUOLA.1.1.5/changelog.1.1.5.txt">changelog.txt</a>.
+tarball and its <a href="resources/TAUOLA.1.1.10/svn_info_tauola.1.1.10.txt">revision info</a> SVN tag, tarball
+creation date/time, etc. For updates with respect to release 1.0 see <a href="resources/TAUOLA.1.1.10/changelog.1.1.10.txt">changelog.txt</a>, for Tauspinner technical documentation see also arXiv:1802.05459 2407.17282 2506.15213 2512.22971
 
-- Note: LCG Generator Services Subproject provides compiled, platform adapted tar balls of our program versions 1.0.2-1.0.7.
-  For newer versions only source code is available through Genser website. Tauola++ Genser distributions can be found
-  <a href="http://service-spi.web.cern.ch/service-spi/external/MCGenerators/distribution/tauola++/">here</a>.
+ <b>IMPORTANT NOTE:</b> Starting from release v1.1.8 we have added HepMC3 support (HepMC3 is avialble on the official <a href="https://hepmc.web.cern.ch/hepmc/">HepMC website</a>).
+ HEPEVT and HepMC libraries are now separated, which means <b>changes to the list of linked libraries are necessary</b>.
 
  @section developement Developement version
-
- The source code and documentation are updated daily from the repository as well. The following files are provided for download of the developement version:
+  
+ The following files are provided for download of the developement version:
  - <a href="resources/TAUOLA.development.version/Tauola_interface_design.development.version.pdf">Tauola_interface_design.pdf</a> full software documentation.
  - <a href="resources/TAUOLA.development.version/TAUOLA.development.version-LHC.tar.gz">TAUOLA source code for the LHC</a>
 (or <a href="resources/TAUOLA.development.version/TAUOLA.development.version.tar.gz">TAUOLA source code with full TAUOLA FORTRAN</a>) tarball and its <a href="resources/TAUOLA.development.version/svn_info_tauola.development.version.txt">revision info</a> SVN tag, tarball creation date/time, etc.
-For updates  with respect to release 1.0 see <a href="resources/TAUOLA.development.version/changelog.development.version.txt">changelog.txt</a>.
+For updates  with respect to release 1.0 see <a href="resources/TAUOLA.development.version/changelog.development.version.txt">changelog.txt</a>, for Tauspinner technical documentation on electroweak corrections see also arXiv:1808.08616 .
 
  @section download Older releases
 
+
  The source code and documentation for release 1.0. The following files are provided for download:
  - <a href="http://arxiv.org/abs/1002.0543">arXiv:1002.0543</a> full software documentation.
  - <a href="resources/TAUOLA.1.0.tar.gz">TAUOLA source code </a> tarball.
@@ -132,6 +132,67 @@ the preprint version.
 tarball and its <a href="resources/TAUOLA.1.1.4/svn_info_tauola.1.1.4.txt">revision info</a> SVN tag, tarball
 creation date/time, etc. For updates with respect to release 1.0 see <a href="resources/TAUOLA.1.1.4/changelog.1.1.4.txt">changelog.txt</a>.
 
+ The source code and documentation for release 1.1.5
+ - <a href="resources/TAUOLA.1.1.5/Tauola_interface_design.1.1.5.pdf">Tauola_interface_design.1.1.5.pdf</a> full software documentation includes updates with respect to
+the preprint version.
+ - <a href="resources/TAUOLA.1.1.5/TAUOLA.1.1.5-LHC.tar.gz">TAUOLA source code for the LHC</a>
+(or <a href="resources/TAUOLA.1.1.5/TAUOLA.1.1.5.tar.gz">TAUOLA source code with full TAUOLA FORTRAN</a>
+ enabling changes of code/models for tau decay hadronic currents)
+tarball and its <a href="resources/TAUOLA.1.1.5/svn_info_tauola.1.1.5.txt">revision info</a> SVN tag, tarball
+creation date/time, etc. For updates with respect to release 1.0 see <a href="resources/TAUOLA.1.1.5/changelog.1.1.5.txt">changelog.txt</a>.
+
+ The source code and documentation for Tauola release 1.1.6  (and of TauSpinner release 2.0.0)
+ - <a href="resources/TAUOLA.1.1.6/Tauola_interface_design.1.1.6.pdf">Tauola_interface_design.1.1.6.pdf</a> full software documentation includes updates with respect to
+the preprint version.
+ - <a href="resources/TAUOLA.1.1.6/TAUOLA.1.1.6-LHC.tar.gz">TAUOLA source code for the LHC</a>
+(or <a href="resources/TAUOLA.1.1.6/TAUOLA.1.1.6.tar.gz">TAUOLA source code with full TAUOLA FORTRAN</a>
+ enabling changes of code/models for tau decay hadronic currents)
+tarball and its <a href="resources/TAUOLA.1.1.6/svn_info_tauola.1.1.6.txt">revision info</a> SVN tag, tarball
+creation date/time, etc. For updates with respect to release 1.0 see <a href="resources/TAUOLA.1.1.6/changelog.1.1.6.txt">changelog.txt</a>.
+
+ The source code and documentation for Tauola release 1.1.6b  (and of TauSpinner release 2.0.1) 
+ - <a href="resources/TAUOLA.1.1.6b/Tauola_interface_design.1.1.6b.pdf">Tauola_interface_design.1.1.6b.pdf</a> full software documentation includes updates with respect to
+the preprint version.
+ - <a href="resources/TAUOLA.1.1.6b/TAUOLA.1.1.6b-LHC.tar.gz">TAUOLA source code for the LHC</a>
+(or <a href="resources/TAUOLA.1.1.6b/TAUOLA.1.1.6b.tar.gz">TAUOLA source code with full TAUOLA FORTRAN</a>
+ enabling changes of code/models for tau decay hadronic currents)
+tarball and its <a href="resources/TAUOLA.1.1.6b/svn_info_tauola.1.1.6b.txt">revision info</a> SVN tag, tarball
+creation date/time, etc. For updates with respect to release 1.0 see <a href="resources/TAUOLA.1.1.6b/changelog.1.1.6b.txt">changelog.txt</a>.
+
+ The source code and documentation for Tauola release 1.1.6c  (and of TauSpinner release 2.0.3) 
+ - <a href="resources/TAUOLA.1.1.6c/Tauola_interface_design.1.1.6c.pdf">Tauola_interface_design.1.1.6c.pdf</a> full software documentation includes updates with respect to
+the preprint version.
+ - <a href="resources/TAUOLA.1.1.6c/TAUOLA.1.1.6c-LHC.tar.gz">TAUOLA source code for the LHC</a>
+(or <a href="resources/TAUOLA.1.1.6c/TAUOLA.1.1.6c.tar.gz">TAUOLA source code with full TAUOLA FORTRAN</a>
+ enabling changes of code/models for tau decay hadronic currents)
+tarball and its <a href="resources/TAUOLA.1.1.6c/svn_info_tauola.1.1.6c.txt">revision info</a> SVN tag, tarball
+creation date/time, etc. For updates with respect to release 1.0 see <a href="resources/TAUOLA.1.1.6c/changelog.1.1.6c.txt">changelog.txt</a>.
+ - Note: on some platforms the cpp pre-compiler which we use for archiving versions of fortran add into the code gnu licence in c++ comment format. This issue started with gcc 4.8.2. It has been fixed in new release.
+ - Solution: in TAUOLA/make.inc set: CPPFLAGS= -C -P -traditional-cpp -nostdinc
+
+
+ The source code and documentation for Tauola release 1.1.8 (and of TauSpinner release 2.0.6) 
+ - <a href="resources/TAUOLA.1.1.8/Tauola_interface_design.1.1.8.pdf">Tauola_interface_design.1.1.8.pdf</a> full software documentation includes updates with respect to
+the preprint version.
+ - <a href="resources/TAUOLA.1.1.8/TAUOLA.1.1.8-LHC.tar.gz">TAUOLA source code for the LHC</a>
+(or <a href="resources/TAUOLA.1.1.8/TAUOLA.1.1.8.tar.gz">TAUOLA source code with full TAUOLA FORTRAN</a>
+ enabling changes of code/models for tau decay hadronic currents)
+tarball and its <a href="resources/TAUOLA.1.1.8/svn_info_tauola.1.1.8.txt">revision info</a> SVN tag, tarball
+creation date/time, etc. For updates with respect to release 1.0 see <a href="resources/TAUOLA.1.1.8/changelog.1.1.8.txt">changelog.txt</a>, for Tauspinner technical documentation see also arXiv:1802.05459.
+
+ The source code and documentation for Tauola release 1.1.9 (and of TauSpinner release 2.1.2) 
+ - <a href="resources/TAUOLA.1.1.9/Tauola_interface_design.1.1.9.pdf">Tauola_interface_design.1.1.9.pdf</a> full software documentation includes updates with respect to
+the preprint version.
+ - <a href="resources/TAUOLA.1.1.9/TAUOLA.1.1.9-LHC.tar.gz">TAUOLA source code for the LHC</a>
+(or <a href="resources/TAUOLA.1.1.9/TAUOLA.1.1.9.tar.gz">TAUOLA source code with full TAUOLA FORTRAN</a>
+ enabling changes of code/models for tau decay hadronic currents)
+tarball and its <a href="resources/TAUOLA.1.1.9/svn_info_tauola.1.1.9.txt">revision info</a> SVN tag, tarball
+creation date/time, etc. For updates with respect to release 1.0 see <a href="resources/TAUOLA.1.1.9/changelog.1.1.9.txt">changelog.txt</a>, for Tauspinner technical documentation see also arXiv:1802.05459 2407.17282 
+
+
+ <b>IMPORTANT NOTE:</b> Starting from release v1.1.8 we have added HepMC3 support (HepMC3 is avialble on the official <a href="https://hepmc.web.cern.ch/hepmc/">HepMC website</a>).
+ HEPEVT and HepMC libraries are now separated, which means <b>changes to the list of linked libraries are necessary</b>.
+
  @section intro Introduction/Status
 
  At present (since Feb 2 2010) the C++ interface functionality for TAUOLA is  complete.
@@ -279,5 +340,5 @@ See software documentation in pdf form.
 -->
 
  <hr>
-Last update 27 September 2013.
+Last update; usually last night by the robot, see the doxygen time below and revision info of the development version.
 */
